| fizzbuzz | R Documentation |
Implements fizzbuzz
fizzbuzz(x)
x |
Numeric vector to run the fizzbuzz algorithm on |
A character vector containing numbers, fizz, buzz or fizzbuzz
fizzbuzz(1:10) fizzbuzz(1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.